@@ -2,6 +2,8 @@
 #define AZLYRICSDOWNLOADER_H
 
 #include <QDebug>
+#include <QtNetwork/QNetworkReply>
+#include <QtNetwork/QNetworkAccessManager>
 
 #include "lyricsDownloader.h"
 
@@ -16,11 +18,11 @@ public:
     //virtual short perform(string a, string t);
 
 protected:
-    //virtual CURLcode download(const string& a, const string& t);
-    virtual string toProviderCode(const string& artist, const string& track) const;
+
+    //virtual QNetworkReply::NetworkError download(const QString& a, const QString& t);
+    virtual QString toProviderCode(const QString& artist, const QString& track) const;
     virtual bool parse();
     /**/
-    static const QString rooturl;
-    static const QRegExp startcomment, endcomment; // comments in the azlyrics.com website which indicate start and end of lyrics
+    static const QString rooturl, startcomment, endcomment; // comments in the azlyrics.com website which indicate start and end of lyrics
 };
 #endif // AZLYRICSDOWNLOADER_H
