@@ -7,7 +7,7 @@ class LyricWikiDownloader : public lyricsDownloader
 {
 public:
 protected:
-    virtual string toProviderCode(const string &artist, const string &track) const;
+    virtual QString toProviderCode(const QString &artist, const QString &track) const;
     virtual bool parse();
     static const QString rooturl;
 };
